summaryrefslogtreecommitdiffstats
path: root/kmymoney2/plugins/ofximport/ofximporterplugin.h
diff options
context:
space:
mode:
Diffstat (limited to 'kmymoney2/plugins/ofximport/ofximporterplugin.h')
-rw-r--r--kmymoney2/plugins/ofximport/ofximporterplugin.h61
1 files changed, 31 insertions, 30 deletions
diff --git a/kmymoney2/plugins/ofximport/ofximporterplugin.h b/kmymoney2/plugins/ofximport/ofximporterplugin.h
index b665439..36473d8 100644
--- a/kmymoney2/plugins/ofximport/ofximporterplugin.h
+++ b/kmymoney2/plugins/ofximport/ofximporterplugin.h
@@ -24,7 +24,7 @@
// ----------------------------------------------------------------------------
// QT Includes
-#include <qstringlist.h>
+#include <tqstringlist.h>
// ----------------------------------------------------------------------------
// Library Includes
@@ -35,7 +35,7 @@
// Project Includes
#include "../kmymoneyplugin.h"
-class KOnlineBankingStatus;
+class KOnlineBankingtqStatus;
/**
@author Ace Jones
@@ -43,8 +43,9 @@ class KOnlineBankingStatus;
class OfxImporterPlugin : public KMyMoneyPlugin::Plugin, public KMyMoneyPlugin::ImporterPlugin, public KMyMoneyPlugin::OnlinePlugin
{
Q_OBJECT
+ TQ_OBJECT
public:
- OfxImporterPlugin(QObject *parent = 0, const char *name = 0, const QStringList& = QStringList());
+ OfxImporterPlugin(TQObject *tqparent = 0, const char *name = 0, const TQStringList& = TQStringList());
~OfxImporterPlugin();
@@ -52,18 +53,18 @@ public:
* This method returns the english-language name of the format
* this plugin imports, e.g. "OFX"
*
* @return QString Name of the format
*/
- virtual QString formatName(void) const;
+ virtual TQString formatName(void) const;
/**
* This method returns the filename filter suitable for passing to
* KFileDialog::setFilter(), e.g. "*.ofx *.qfx" which describes how
* files of this format are likely to be named in the file system
*
* @return QString Filename filter string
*/
- virtual QString formatFilenameFilter(void) const;
+ virtual TQString formatFilenameFilter(void) const;
/**
* This method returns whether this plugin is able to import
@@ -73,7 +74,7 @@ public:
*
* @return bool Whether the indicated file is importable by this plugin
*/
- virtual bool isMyFormat( const QString& filename ) const;
+ virtual bool isMyFormat( const TQString& filename ) const;
/**
* Import a file
@@ -82,31 +83,31 @@ public:
*
* @return bool Whether the import was successful.
*/
- virtual bool import( const QString& filename );
+ virtual bool import( const TQString& filename );
/**
* Returns the error result of the last import
*
* @return QString English-language name of the error encountered in the
* last import, or QString() if it was successful.
*
*/
- virtual QString lastError(void) const;
+ virtual TQString lastError(void) const;
- QWidget* accountConfigTab(const MyMoneyAccount& acc, QString& name);
+ TQWidget* accountConfigTab(const MyMoneyAccount& acc, TQString& name);
MyMoneyKeyValueContainer onlineBankingSettings(const MyMoneyKeyValueContainer& current);
- const MyMoneyAccount& account(const QString& key, const QString& value) const;
+ const MyMoneyAccount& account(const TQString& key, const TQString& value) const;
- void protocols(QStringList& protocolList) const;
+ void protocols(TQStringList& protocolList) const;
bool mapAccount(const MyMoneyAccount& acc, MyMoneyKeyValueContainer& settings);
bool updateAccount(const MyMoneyAccount& acc, bool moreAccounts);
protected slots:
void slotImportFile(void);
- void slotImportFile(const QString& url);
+ void slotImportFile(const TQString& url);
protected:
void createActions(void);
@@ -114,13 +115,13 @@ protected:
MyMoneyStatement& back(void) { return m_statementlist.back(); }
bool isValid(void) const { return m_valid; }
void setValid(void) { m_valid = true; }
- void addInfo(const QString& _msg ) { m_infos+=_msg; }
- void addWarning(const QString& _msg ) { m_warnings+=_msg; }
- void addError(const QString& _msg ) { m_errors+=_msg; }
- const QStringList& infos(void) const { return m_infos; }
- const QStringList& warnings(void) const { return m_warnings; }
- const QStringList& errors(void) const { return m_errors; }
- bool storeStatements(QValueList<MyMoneyStatement>& statements);
+ void addInfo(const TQString& _msg ) { m_infos+=_msg; }
+ void addWarning(const TQString& _msg ) { m_warnings+=_msg; }
+ void addError(const TQString& _msg ) { m_errors+=_msg; }
+ const TQStringList& infos(void) const { return m_infos; }
+ const TQStringList& warnings(void) const { return m_warnings; }
+ const TQStringList& errors(void) const { return m_errors; }
+ bool storeStatements(TQValueList<MyMoneyStatement>& statements);
bool importStatement(const MyMoneyStatement& s);
@@ -133,13 +134,13 @@ protected:
private:
bool m_valid;
bool m_preferName;
- QValueList<MyMoneyStatement> m_statementlist;
- QValueList<MyMoneyStatement::Security> m_securitylist;
- QString m_fatalerror;
- QStringList m_infos;
- QStringList m_warnings;
- QStringList m_errors;
- KOnlineBankingStatus* m_statusDlg;
+ TQValueList<MyMoneyStatement> m_statementlist;
+ TQValueList<MyMoneyStatement::Security> m_securitylist;
+ TQString m_fatalerror;
+ TQStringList m_infos;
+ TQStringList m_warnings;
+ TQStringList m_errors;
+ KOnlineBankingtqStatus* m_statusDlg;
};
#endif
@@ -52,18 +53,18 @@ public:
* this plugin imports, e.g. "OFX"
*
- * @return QString Name of the format
+ * @return TQString Name of the format
*/
@@ -52,18 +53,18 @@ public:
* files of this format are likely to be named in the file system
*
- * @return QString Filename filter string
+ * @return TQString Filename filter string
*/
@@ -82,31 +83,31 @@ public:
* Returns the error result of the last import
*
- * @return QString English-language name of the error encountered in the
- * last import, or QString() if it was successful.
+ * @return TQString English-language name of the error encountered in the
+ * last import, or TQString() if it was successful.
*
*/